@@ -1,10 +1,9 @@
 from builtins import next
 from builtins import object
-from collections import namedtuple
-from dateutil.tz import tzutc
 
 import mock
-from dateutil.tz import tzoffset, datetime
+from collections import namedtuple
+from dateutil.tz import datetime
 from dateutil.tz.tz import tzutc
 
 from bugwarrior.services.jira import JiraService
@@ -40,7 +39,9 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
             'summary': arbitrary_summary,
             'timeestimate': arbitrary_estimation,
             'created': '2016-06-06T06:07:08.123-0700',
-            'fixVersions': [{'name': '1.2.3'}]
+            'fixVersions': [{'name': '1.2.3'}],
+            'issuetype': {'name': 'Epic'},
+            'status': {'name': 'Open'}
         },
         'key': '%s-%s' % (arbitrary_project, arbitrary_id, ),
     }
@@ -60,6 +61,7 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
         service = super(TestJiraIssue, self).get_mock_service(*args, **kwargs)
         service.jira = FakeJiraClient(self.arbitrary_record)
         service.sprint_field_names = ['Sprint']
+        service.import_sprints_as_tags = True
         return service
 
     def test_to_taskwarrior(self):
@@ -83,6 +85,8 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
             'tags': [],
             'entry': datetime.datetime(2016, 6, 6, 13, 7, 8, tzinfo=tzutc()),
             'jirafixversion': '1.2.3',
+            'jiraissuetype': 'Epic',
+            'jirastatus': 'Open',
 
             issue.URL: arbitrary_url,
             issue.FOREIGN_ID: self.arbitrary_record['key'],
@@ -99,6 +103,53 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
 
         self.assertEqual(actual_output, expected_output)
 
+    def test_to_taskwarrior_sprint_with_goal(self):
+        record_with_goal = self.arbitrary_record.copy()
+        record_with_goal['fields'] = self.arbitrary_record_with_due['fields'].copy()
+        record_with_goal['fields']['Sprint'] = [
+            'com.atlassian.greenhopper.service.sprint.Sprint@4c9c41a5[id=2322,rapidViewId=1173,\
+            state=ACTIVE,name=Sprint 1,goal=Do foo, bar, baz,startDate=2016-09-06T16:08:07.4\
+            55Z,endDate=2016-09-23T16:08:00.000Z,completeDate=<null>,sequence=2322]'
+        ]
+        arbitrary_url = 'http://one'
+        arbitrary_extra = {
+            'jira_version': 5,
+            'annotations': ['an annotation'],
+        }
+
+        issue = self.service.get_issue_for_record(
+            record_with_goal, arbitrary_extra
+        )
+
+        expected_output = {
+            'project': self.arbitrary_project,
+            'priority': (
+                issue.PRIORITY_MAP[record_with_goal['fields']['priority']]
+            ),
+            'annotations': arbitrary_extra['annotations'],
+            'due': datetime.datetime(2016, 9, 23, 16, 8, tzinfo=tzutc()),
+            'tags': ['Sprint1'],
+            'entry': datetime.datetime(2016, 6, 6, 13, 7, 8, tzinfo=tzutc()),
+            'jirafixversion': '1.2.3',
+            'jiraissuetype': 'Epic',
+            'jirastatus': 'Open',
+
+            issue.URL: arbitrary_url,
+            issue.FOREIGN_ID: record_with_goal['key'],
+            issue.SUMMARY: self.arbitrary_summary,
+            issue.DESCRIPTION: None,
+            issue.ESTIMATE: self.arbitrary_estimation / 60 / 60
+        }
+
+        def get_url(*args):
+            return arbitrary_url
+
+        with mock.patch.object(issue, 'get_url', side_effect=get_url):
+            actual_output = issue.to_taskwarrior()
+
+        self.assertEqual(actual_output, expected_output)
+
+
     def test_issues(self):
         issue = next(self.service.issues())
 
@@ -111,6 +162,8 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
             'jiraestimate': 1,
             'jirafixversion': '1.2.3',
             'jiraid': 'DONUT-10',
+            'jiraissuetype': 'Epic',
+            'jirastatus': 'Open',
             'jirasummary': 'lkjaldsfjaldf',
             'jiraurl': 'two/browse/DONUT-10',
             'priority': 'H',
@@ -121,6 +174,6 @@ class TestJiraIssue(AbstractServiceTest, ServiceTest):
 
     def test_get_due(self):
         issue = self.service.get_issue_for_record(
-            self.arbitrary_record_with_due            
+            self.arbitrary_record_with_due
         )
         self.assertEqual(issue.get_due(), datetime.datetime(2016, 9, 23, 16, 8, tzinfo=tzutc()))
